package Catmandu::LDAP;

=head1 NAME

Catmandu::LDAP - Catmandu modules for working with LDAP directories

=head1 VERSION

Version 0.0102

=cut

our $VERSION = '0.0102';

=head1 MODULES

=over

=item * L<Catmandu::Importer::LDAP>

=back

=head1 AUTHOR

Nicolas Steenlant, C<< <nicolas.steenlant at ugent.be> >>

=head1 LICENSE AND COPYRIGHT

Copyright 2012 Ghent University Library

This program is free software; you can redistribute it and/or modify it
under the terms of either: the GNU General Public License as published
by the Free Software Foundation; or the Artistic License.

See http://dev.perl.org/licenses/ for more information.

=cut

1;

